@@ -55,6 +55,12 @@ class AbstractRunner(ABC):
 
 class SimpleEnsemblingRunner(AbstractRunner):
     def runTrial(self, saver, seed,  n, s, low_bound, up_bound):
+        try:
+            self.wrappedRunTrial(saver, seed, n, s, low_bound, up_bound)
+        except Exception as e:
+            print(e)
+
+    def wrappedRunTrial(self, saver, seed,  n, s, low_bound, up_bound):
         meArg = (seed, n, s, low_bound, up_bound)
         meArgList = list(meArg)
         meArgList = [str(it) for it in meArgList]
